<?php
/**
 * Class for Mondial Relay shipping modes.
 */
declare(strict_types=1);

defined( 'ABSPATH' ) || exit;

/**
 * Class MRWP_modes
 */
class MRWP_modes
{
    private static $modes;
    private static $hmr;

    private static function init_modes()
    {
        self::$modes = array(
            '24R' => __('24R - livraison en Point Relais®', 'mondialrelay-wordpress'),
            'HOM' => __('HOM - livraison domicile HOME', 'mondialrelay-wordpress'),
            'DRI' => __('DRI - livraison en Colis Drive (indisponible avec l’offre Start)', 'mondialrelay-wordpress'),
            'HOC' => __('HOC - livraison HOC (indisponible avec l’offre Start)', 'mondialrelay-wordpress'),
            'HOD' => __('HOD - livraison HOD (indisponible avec l’offre Start)', 'mondialrelay-wordpress')
        );
        self::$hmr = array(
            'HMR' => __('Livraison hors Mondial Relay', 'mondialrelay-wordpress'),
        );
    }

    public static function all_modes()
    {
        self::init_modes();

        return array_keys( self::$modes );
    }

    public static function all_modes_as_options( $selected )
    {
        self::init_modes();
        $html = '';
        foreach ( self::$modes as $code => $label ) {
            $html .= sprintf(
                "<option %s value='%s'>%s</option>\n",
                selected( $selected, $code, false ),
                esc_attr( $code ),
                esc_html( $label )
            );
        }

        return $html;
    }

    public static function all_labels()
    {
        self::init_modes();

        return self::$modes;
    }

    public static function all_labels_with_hmr()
    {
        self::init_modes();

        return self::$modes + self::$hmr;
    }

}
